@@ -30,6 +30,7 @@ module Data.Hourglass
     , isLeapYear
     , getWeekDay
     , getDayOfTheYear
+    , daysInMonth
     ) where
 
 import Data.Hourglass.Time
@@ -37,4 +38,4 @@ import Data.Hourglass.Format
 import Data.Hourglass.Types
 import Data.Hourglass.Local
 import Data.Hourglass.Zone
-import Data.Hourglass.Calendar (isLeapYear, getWeekDay, getDayOfTheYear)
+import Data.Hourglass.Calendar (isLeapYear, getWeekDay, getDayOfTheYear, daysInMonth)
